==> apache-nuttx-apps-10.2.0-incubating.tar.gz: apps/examples/watcher/wdt.h <==
/****************************************************************************
 * apps/examples/watcher/wdt.h
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

#ifndef __EXAMPLES_WATCHER_WDT_H
#define __EXAMPLES_WATCHER_WDT_H

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>
#include <nuttx/timers/watchdog.h>

/****************************************************************************
 * Pre-processor Definitions
 ****************************************************************************/

#define DEVNAME_SIZE      16

/****************************************************************************
 * Public Types
 ****************************************************************************/

struct wdog_params_s
{
    uint32_t timeout;
    char devname[DEVNAME_SIZE];
    struct watchdog_capture_s handlers;
};

/****************************************************************************
 * Public Data
 ****************************************************************************/

/****************************************************************************
 * Public Function Prototypes
 ****************************************************************************/

int wdt_init(void);
void wdt_feed_the_dog(void);

#endif                                 /* __EXAMPLES_WATCHER_WDT_H */

==> apache-nuttx-apps-11.0.0-incubating.tar.gz: apps/examples/watcher/wdt.h <==
/****************************************************************************
 * apps/examples/watcher/wdt.h
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

#ifndef __APPS_EXAMPLES_WATCHER_WDT_H
#define __APPS_EXAMPLES_WATCHER_WDT_H

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>
#include <nuttx/timers/watchdog.h>

/****************************************************************************
 * Pre-processor Definitions
 ****************************************************************************/

#define DEVNAME_SIZE      16

/****************************************************************************
 * Public Types
 ****************************************************************************/

struct wdog_params_s
{
    uint32_t timeout;
    char devname[DEVNAME_SIZE];
    struct watchdog_capture_s handlers;
};

/****************************************************************************
 * Public Data
 ****************************************************************************/

/****************************************************************************
 * Public Function Prototypes
 ****************************************************************************/

int wdt_init(void);
void wdt_feed_the_dog(void);

#endif /* __APPS_EXAMPLES_WATCHER_WDT_H */
